#[repr(transparent)]pub struct Ability_NativeChildProcessErrorCode(pub NonZero<c_uint>);api-12 only.Expand description
Enumerates the error codes used by the native child process module.
Available since API-level: 12
Tuple Fields
0: NonZero<c_uint>Implementations
Sourceimpl Ability_NativeChildProcessErrorCode
impl Ability_NativeChildProcessErrorCode
Sourcepub const INVALID_PARAM: Ability_NativeChildProcessErrorCode
pub const INVALID_PARAM: Ability_NativeChildProcessErrorCode
Invalid parameter.
Sourcepub const NOT_SUPPORTED: Ability_NativeChildProcessErrorCode
pub const NOT_SUPPORTED: Ability_NativeChildProcessErrorCode
Creating a native child process is not supported.
Sourcepub const INTERNAL: Ability_NativeChildProcessErrorCode
pub const INTERNAL: Ability_NativeChildProcessErrorCode
Internal error.
Sourcepub const BUSY: Ability_NativeChildProcessErrorCode
pub const BUSY: Ability_NativeChildProcessErrorCode
A new child process cannot be created during the startup of another native child process. You can try again after the child process is started.
Sourcepub const TIMEOUT: Ability_NativeChildProcessErrorCode
pub const TIMEOUT: Ability_NativeChildProcessErrorCode
Starting the native child process times out.
Sourcepub const SERVICE_ERROR: Ability_NativeChildProcessErrorCode
pub const SERVICE_ERROR: Ability_NativeChildProcessErrorCode
Server error.
Sourcepub const MULTI_PROCESS_DISABLED: Ability_NativeChildProcessErrorCode
pub const MULTI_PROCESS_DISABLED: Ability_NativeChildProcessErrorCode
The multi-process mode is disabled. A child process cannot be started.
Sourcepub const ALREADY_IN_CHILD: Ability_NativeChildProcessErrorCode
pub const ALREADY_IN_CHILD: Ability_NativeChildProcessErrorCode
A process cannot be created in a child process.
Sourcepub const MAX_CHILD_PROCESSES_REACHED: Ability_NativeChildProcessErrorCode
pub const MAX_CHILD_PROCESSES_REACHED: Ability_NativeChildProcessErrorCode
The number of native child processes reaches the maximum.
Sourcepub const LIB_LOADING_FAILED: Ability_NativeChildProcessErrorCode
pub const LIB_LOADING_FAILED: Ability_NativeChildProcessErrorCode
The child process fails to load the dynamic library because the file does not exist or the corresponding method is not implemented or exported.
Sourcepub const CONNECTION_FAILED: Ability_NativeChildProcessErrorCode
pub const CONNECTION_FAILED: Ability_NativeChildProcessErrorCode
The child process fails to call the OnConnect method of the dynamic library. An invalid IPC object pointer may be returned.
Sourcepub const CALLBACK_NOT_EXIST: Ability_NativeChildProcessErrorCode
Available on crate feature api-20 only.
pub const CALLBACK_NOT_EXIST: Ability_NativeChildProcessErrorCode
api-20 only.The callback does not exist; it may not have been registered or has already been unregistered.
Available since API-level: 20