#[repr(transparent)]pub struct NativeChildProcess_IsolationMode(pub c_uint);Available on crate features
api-12 and api-13 only.Expand description
Enumerates the isolation modes used by the native child process module.
Available since API-level: 13
Tuple Fields
0: c_uintImplementations
Sourceimpl NativeChildProcess_IsolationMode
impl NativeChildProcess_IsolationMode
Sourcepub const NCP_ISOLATION_MODE_NORMAL: NativeChildProcess_IsolationMode
pub const NCP_ISOLATION_MODE_NORMAL: NativeChildProcess_IsolationMode
Normal isolation mode, parent process shares the same sandbox or internet with the child process.
Sourcepub const NCP_ISOLATION_MODE_ISOLATED: NativeChildProcess_IsolationMode
pub const NCP_ISOLATION_MODE_ISOLATED: NativeChildProcess_IsolationMode
Isolated mode, parent process does not share the same sandbox or internet with the child process.