pub unsafe extern "C" fn OH_AbilityRuntime_ApplicationContextGetDistributedFilesDir(
buffer: *mut c_char,
bufferSize: i32,
writeLength: *mut i32,
) -> AbilityRuntimeResultAvailable on crate feature
api-16 only.Expand description
Obtain the distributed files directory of the application.
Arguments
-
buffer- A pointer to a buffer that receives the distributed files directory of the application. -
bufferSize- The length of the buffer. -
writeLength- The string length actually written to the buffer, when returning [ABILITY_RUNTIME_ERROR_CODE_NO_ERROR].
Returns
- The error code.
[
ABILITY_RUNTIME_ERROR_CODE_NO_ERROR] if the operation is successful. [ABILITY_RUNTIME_ERROR_CODE_PARAM_INVALID] if the buffer or writeLength is null, or the buffer size is less than the minimum buffer size. [ABILITY_RUNTIME_ERROR_CODE_CONTEXT_NOT_EXIST] if the application context does not exist.
Available since API-level: 16